==> dif-core-2.1.9-1-20151124.172801-2-sources.jar: pt/digitalis/dif/dem/annotations/AnnotationMemberTags.java <==
/**
 * 2007, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.dem.annotations;

/**
 * This class defines the annotation member names as String constant.
 * 
 * @author Rodrigo Gonalves <a href="mailto:rgoncalves@digitalis.pt">rgoncalves@digitalis.pt</a><br/>
 * @created 2007/11/21
 */
final public class AnnotationMemberTags {

    /** Java's annotation 'value' member tag. */
    final static public String ANNOTATION_VALUE = "value";

    /** ApplicationDefinition 'provider' member tag. */
    final static public String APPLICATION_DEFINITION_PROVIDER = "provider";

    /** DispatcherMode 'authenticate' member tag. */
    final static public String DISPATCHER_MODE_AUTHENTICATE = "authenticate";

    /** DispatcherMode 'authorize' member tag. */
    final static public String DISPATCHER_MODE_AUTHORIZE = "authorize";

    /** Entity 'id' member tag. */
    final static public String ENTITY_DEFINITION_ID = "id";

    /** Entity 'name' member tag. */
    final static public String ENTITY_DEFINITION_NAME = "name";

    /** ErrorStage 'exceptions' member tag. */
    final static public String ERROR_STAGE_EXCEPTIONS = "exceptions";

    /** ErrorStage 'target' member tag. */
    final static public String ERROR_STAGE_TARGET = "target";

    /** ErrorView 'exceptions' member tag. */
    final static public String ERROR_VIEW_EXCEPTIONS = "exceptions";

    /** Parameter 'constraint' member tag. */
    final static public String PARAMETER_CONSTRAINTS = "constraints";

    /** Parameter 'defaultValue' member tag. */
    final static public String PARAMETER_DEFAULT_VALUE = "defaultValue";

    /** Parameter 'id' member tag. */
    final static public String PARAMETER_ID = "id";

    /** Parameter 'linkToForm' member tag. */
    final static public String PARAMETER_LINK_TO_FORM = "linkToForm";

    /** Parameter 'regexp' member tag. */
    final static public String PARAMETER_REGEXP_VALUE = "regexp";

    /** Persist 'repository' member tag. */
    final static public String PERSIST_ALLOW_ANONYMOUS = "allowAnonymous";

    /** Persist 'groupVisibility' member tag. */
    final static public String PERSIST_GROUP_VISIBILITY = "groupVisibility";

    /** Persist 'repository' member tag. */
    final static public String PERSIST_REPOSITORY = "repository";

    /** Persist 'scope' member tag. */
    final static public String PERSIST_SCOPE = "scope";

    /** ProviderDefinition 'defaultProvider' member tag. */
    final static public String PROVIDER_DEFINITION_DEFAULT_PROVIDER = "defaultProvider";

    /** Rule 'action' member tag. */
    final static public String RULE_ACTION = "action";

    /** Rule 'first' member tag. */
    final static public String RULE_FIRST = "first";

    /** Rule 'ruleID' member tag. */
    final static public String RULE_ID = "ruleId";

    /** Rule 'last' member tag. */
    final static public String RULE_LAST = "last";

    /** Rule 'parameters' member tag. */
    final static public String RULE_PARAMETER_LIST = "parameters";

    /** Rule 'value' member tag. */
    final static public String RULE_VALUE = "value";

    /** ServiceDefinition 'application' member tag. */
    final static public String SERVICE_DEFINITION_APPLICATION = "application";

    /** StageDefinition 'service' member tag. */
    final static public String STAGE_DEFINITION_SERVICE = "service";

    /** Stage definition 'overrideDefault' member tag. */
    final static public String STAGE_OVERRIDE_DEFAULT = "overrideDefault";

    /** Rule 'parameters' member tag. */
    final static public String VALUE = "value";

    /** View 'engine' member tag. */
    final static public String VIEW_ENGINE = "engine";

    /** ErrorView 'isDefault' member tag. */
    final static public String VIEW_IS_DEFAULT = "defaultView";

    /** View 'target' member tag. */
    final static public String VIEW_TARGET = "target";

}

==> dif-core-2.6.0-sources.jar: pt/digitalis/dif/dem/annotations/AnnotationMemberTags.java <==
/**
 * 2007, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.dem.annotations;

/**
 * This class defines the annotation member names as String constant.
 *
 * @author Rodrigo Gonalves <a href="mailto:rgoncalves@digitalis.pt">rgoncalves@digitalis.pt</a><br/>
 * @created 2007/11/21
 */
final public class AnnotationMemberTags
{

    /** Java's annotation 'value' member tag. */
    final static public String ANNOTATION_VALUE = "value";

    /** ApplicationDefinition 'provider' member tag. */
    final static public String APPLICATION_DEFINITION_PROVIDER = "provider";

    /** DispatcherMode 'authenticate' member tag. */
    final static public String DISPATCHER_MODE_AUTHENTICATE = "authenticate";

    /** DispatcherMode 'authorize' member tag. */
    final static public String DISPATCHER_MODE_AUTHORIZE = "authorize";

    /** Entity 'id' member tag. */
    final static public String ENTITY_DEFINITION_ID = "id";

    /** Entity 'name' member tag. */
    final static public String ENTITY_DEFINITION_NAME = "name";

    /** ErrorStage 'exceptions' member tag. */
    final static public String ERROR_STAGE_EXCEPTIONS = "exceptions";

    /** ErrorStage 'target' member tag. */
    final static public String ERROR_STAGE_TARGET = "target";

    /** ErrorView 'exceptions' member tag. */
    final static public String ERROR_VIEW_EXCEPTIONS = "exceptions";

    /** The Constant FORM_CONFIGURABLE_MANDATORY. */
    final static public String FORM_CONFIGURABLE_CAN_EDIT_MANDATORY = "canEditMandatory";

    /** The Constant FORM_CONFIGURABLE_READONLY. */
    final static public String FORM_CONFIGURABLE_CAN_EDIT_READONLY = "canEditReadOnly";

    /** The Constant FORM_CONFIGURABLE_CAN_EDIT_TEXT. */
    final static public String FORM_CONFIGURABLE_CAN_EDIT_TEXT = "canEditText";

    /** Parameter 'constraint' member tag. */
    final static public String PARAMETER_CONSTRAINTS = "constraints";

    /** Parameter 'defaultValue' member tag. */
    final static public String PARAMETER_DEFAULT_VALUE = "defaultValue";

    /** Parameter 'id' member tag. */
    final static public String PARAMETER_ID = "id";

    /** Parameter 'linkToForm' member tag. */
    final static public String PARAMETER_LINK_TO_FORM = "linkToForm";

    /** Parameter 'regexp' member tag. */
    final static public String PARAMETER_REGEXP_VALUE = "regexp";

    /** Parameter 'trusted' member tag. */
    final static public String PARAMETER_TRUSTED = "trusted";

    /** Persist 'repository' member tag. */
    final static public String PERSIST_ALLOW_ANONYMOUS = "allowAnonymous";

    /** The Constant PERSIST_CONTEXT. */
    final static public String PERSIST_CONTEXT = "context";

    /** Persist 'groupVisibility' member tag. */
    final static public String PERSIST_GROUP_VISIBILITY = "groupVisibility";

    /** Persist 'repository' member tag. */
    final static public String PERSIST_REPOSITORY = "repository";

    /** Persist 'scope' member tag. */
    final static public String PERSIST_SCOPE = "scope";

    /** ProviderDefinition 'defaultProvider' member tag. */
    final static public String PROVIDER_DEFINITION_DEFAULT_PROVIDER = "defaultProvider";

    /** Rule 'action' member tag. */
    final static public String RULE_ACTION = "action";

    /** Rule 'first' member tag. */
    final static public String RULE_FIRST = "first";

    /** Rule 'ruleID' member tag. */
    final static public String RULE_ID = "ruleId";

    /** Rule 'last' member tag. */
    final static public String RULE_LAST = "last";

    /** Rule 'parameters' member tag. */
    final static public String RULE_PARAMETER_LIST = "parameters";

    /** Rule 'value' member tag. */
    final static public String RULE_VALUE = "value";

    /** ServiceDefinition 'application' member tag. */
    final static public String SERVICE_DEFINITION_APPLICATION = "application";

    /** StageDefinition 'service' member tag. */
    final static public String STAGE_DEFINITION_SERVICE = "service";

    /** Stage definition 'overrideDefault' member tag. */
    final static public String STAGE_OVERRIDE_DEFAULT = "overrideDefault";

    /** Rule 'parameters' member tag. */
    final static public String VALUE = "value";

    /** View 'engine' member tag. */
    final static public String VIEW_ENGINE = "engine";

    /** ErrorView 'isDefault' member tag. */
    final static public String VIEW_IS_DEFAULT = "defaultView";

    /** View 'target' member tag. */
    final static public String VIEW_TARGET = "target";
}
